@@ -193,6 +193,7 @@ static gboolean
 cheese_camera_expose_cb (GtkWidget *widget, GdkEventExpose *event, CheeseCamera *camera)
 {
   CheeseCameraPrivate *priv = CHEESE_CAMERA_GET_PRIVATE (camera);
+  GtkAllocation        allocation;
   GstState             state;
   GstXOverlay         *overlay = GST_X_OVERLAY (gst_bin_get_by_interface (GST_BIN (priv->pipeline),
                                                                           GST_TYPE_X_OVERLAY));
@@ -201,8 +202,10 @@ cheese_camera_expose_cb (GtkWidget *widget, GdkEventExpose *event, CheeseCamera
 
   if ((state < GST_STATE_PLAYING) || (overlay == NULL))
   {
-    gdk_draw_rectangle (widget->window, widget->style->black_gc, TRUE,
-                        0, 0, widget->allocation.width, widget->allocation.height);
+    gtk_widget_get_allocation (widget, &allocation);
+    gdk_draw_rectangle (gtk_widget_get_window (widget),
+                        gtk_widget_get_style (widget)->black_gc, TRUE,
+                        0, 0, allocation.width, allocation.height);
   }
   else
   {
@@ -277,7 +280,9 @@ cheese_camera_bus_message_cb (GstBus *bus, GstMessage *message, CheeseCamera *ca
 
       g_source_remove (priv->eos_timeout_id);
 
-      g_signal_emit (camera, camera_signals[VIDEO_SAVED], 0);
+      /* emit signal by name here as the camera_signals array is empty in this thread */
+      /* TODO: really understand how threads and static works and why this is needed */
+      g_signal_emit_by_name (camera, "video-saved", NULL);
 
       cheese_camera_change_sink (camera, priv->video_display_bin,
                                  priv->photo_save_bin, priv->video_save_bin);
@@ -1246,7 +1251,7 @@ cheese_camera_set_video_format (CheeseCamera *camera, CheeseVideoFormat *format)
 {
   CheeseCameraPrivate *priv;
   g_return_if_fail (CHEESE_IS_CAMERA (camera));
-  g_return_if_fail (format == NULL);
+  g_return_if_fail (format != NULL);
 
   priv = CHEESE_CAMERA_GET_PRIVATE (camera);
 
